@@ -9,7 +9,7 @@ class LightSensorThing(Thing):
     # regarding capabilities refer https://iot.mozilla.org/schemas
     # there is also another schema registry http://iotschema.org/docs/full.html not used by webthing
 
-    def __init__(self, description: str, light_sensor: LightSensor):
+    def __init__(self, description: str, light_sensor: LightSensor, refreshing_rate_sec:int):
         Thing.__init__(
             self,
             'urn:dev:ops:illuminanceSensor-1',
@@ -20,7 +20,7 @@ class LightSensorThing(Thing):
 
         self.ioloop = tornado.ioloop.IOLoop.current()
 
-        light_sensor.listen(self.on_measured)
+        light_sensor.listen(self.on_measured, refreshing_rate_sec)
 
         self.bright = Value(0)
         self.add_property(
@@ -43,8 +43,8 @@ class LightSensorThing(Thing):
         self.bright.notify_of_external_update(brightness)
 
 
-def run_server(port: int, description: str = ""):
-    light_sensor = LightSensorThing(description, LightSensor())
+def run_server(port: int, description: str, sampling_rate_sec: int, smoothing_window_sec: int, refreshing_rate_sec:int):
+    light_sensor = LightSensorThing(description, LightSensor(sampling_rate_sec, smoothing_window_sec), refreshing_rate_sec)
     server = WebThingServer(SingleThing(light_sensor), port=port, disable_host_validation=True)
     try:
         logging.info('starting the server')
